﻿using System.Text;

using anbs_cp.Interfaces;

namespace anbs_cp.Classes.Encrypt;

/// <summary>
/// Ключ шифровки / расшифровки
/// </summary>
public class EncryptKey: IEncryptKey
{
    /// <summary>
    /// Конструктор по умолчанию
    /// </summary>
    /// <param name="key">Ключ в формате массива <see cref="byte"/></param>
    public EncryptKey (byte[] key) => Key = key;

    /// <summary>
    /// Конструктор, принимающий строку и преобразующий в нужный формат
    /// </summary>
    /// <param name="key">Ключ в формате <see cref="string"/></param>
    public EncryptKey (string key) => Key = Encoding.ASCII.GetBytes(key);

    /// <summary>
    /// Ключ
    /// </summary>
    public byte[] Key { get; set; }

    /// <summary>
    /// Получение ключа по умолчанию
    /// </summary>
    /// <returns><see cref="EncryptKey"/></returns>
    public static EncryptKey GetDefault () => new(Enumerable.Range(0, 32).Select(static x => (byte)x).ToArray());

    /// <summary>
    /// Получение класса ключа
    /// </summary>
    /// <param name="key">Ключ в формате массива <see cref="byte"/></param>
    /// <returns><see cref="EncryptKey"/></returns>
    public static EncryptKey GetKey (byte[]? key) => key != null ? new(key) : GetDefault();

    /// <summary>
    /// Получение класса ключа
    /// </summary>
    /// <param name="key">Ключ в формате массива <see cref="byte"/></param>
    /// <returns><see cref="EncryptKey"/></returns>
    public static EncryptKey GetKey (string key) => !string.IsNullOrWhiteSpace(key) ? new(key) : GetDefault();
}